<template>
    <div class="mixing_index">
        <div class="mixing_header">
            <span>中铁十四局通甬站前I标管片场拌和站</span>
        </div>
        <div class="mixing_main">
            <div class="mixing_left">
                <div class="mixing_left_num">
                    <div class="">{{ mixingList.tableNum }}</div>
                </div>
                <div class="mixing_left_name">{{ mixingList.materialName || '' }}</div>
            </div>
            <div class="mixing_right">
                <div class="mixing_rows">
                    <div class="mixing_rows_titles">产地名称：</div>
                    <div class="mixing_rows_datas">{{ mixingList.nameOfOrigin || '' }}</div>
                </div>
                <div class="mixing_rows">
                    <div class="mixing_rows_titles">进场数量：</div>
                    <div class="mixing_rows_datas">{{ mixingList.incomingQuantity || '' }} t</div>
                </div>
                <div class="mixing_rows">
                    <div class="mixing_rows_titles">进场日期：</div>
                    <div class="mixing_rows_datas">{{ mixingList.inTime || '' }}</div>
                </div>
                <div class="mixing_rows">
                    <div class="mixing_rows_titles">检验日期：</div>
                    <div class="mixing_rows_datas">{{ mixingList.inspectionDate || '' }}</div>
                </div>
                <div class="mixing_rows">
                    <div class="mixing_rows_titles">检验状态：</div>
                    <div class="mixing_rows_datas"
                        :class="{ 'standardStyle': mixingList.status === 1, 'notStandardStyle': mixingList.status !== 1 }">
                        {{ mixingList.status === 1 ? '合格' : mixingList.status === 2 ? '待检' : ''
                        }}</div>
                </div>
                <div class="mixing_rows">
                    <div class="mixing_rows_titles">报告编号：</div>
                    <div class="mixing_rows_datas small_size">
                        {{
                            mixingList.reportNumber &&
                            mixingList.reportNumber.replace(/\s/g, '\n')
                        }}
                    </div>
                </div>
            </div>
        </div>
    </div>
</template>
<script>
export default {
    data() {
        return {
            timer: null,//定时器
            mixingList: {},//展示数据
        }
    },
    created() {
        this.searchMixingInfos()
    },
    mounted() {
        const that = this;
        // that.searchMixingInfos()
        that.timer = setInterval(() => {
            that.searchMixingInfos()
        }, 60000 * 10)

        let width = document.getElementsByClassName('mixing_index')[0].clientWidth
        let $html = document.getElementsByTagName('html')[0]
        let fontsize = width / 1920 * 11
        $html.style.fontSize = `${fontsize}px`
        window.onresize = () => {
            let width = document.getElementsByClassName('mixing_index')[0].clientWidth
            let fontsize = width / 1920 * 11
            $html.style.fontSize = `${fontsize}px`
        }
    },
    beforeDestroy() {
        clearInterval(this.timer);
        this.timer = null;
    },
    methods: {
        searchMixingInfos() {
            let params = {
                tableNum: window.location.href.split('/')[5].split('=')[1]
            }
            this.$api.Infos.showHmixings(params).then(res => {
                if (res.statusMsg === 'ok' && res.data) {
                    res.data.reportNumber = "TYZQ1-ZTSS-J1-CGL-20231207-001 TYZQ1-ZTSS-J1-CGL-20231207-002"
                    this.mixingList = res.data
                } else {
                    this.$message.warning('请检查网络或联系管理员!!!')
                }
            })
        },
    }
}
</script>
<style scoped lang="scss">
.mixing_index {
    display: flex;
    flex-direction: column;
    width: 100%;
    height: 100%;
    padding: 0.4rem;
    background: url("../../assets/mixing/mixing_bg3.png") no-repeat;
    background-size: 100% 100%;
    background-position: center center;


    .mixing_header {
        width: 100%;
        height: 9rem;
        position: relative;
        display: flex;
        justify-content: center;
        align-items: center;

        span {
            position: absolute;
            font-size: 5rem;
            font-weight: bold;
            letter-spacing: 2px;
            text-shadow: 0px 3px 3px rgba(25, 63, 95, 0.05);
            background: -webkit-linear-gradient(90deg, #2AC0FF 0%, #FFFFFF 70%);
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
        }
    }

    .mixing_main {
        overflow: hidden;
        flex: 1;
        width: 100%;
        height: 100%;
        padding: 3rem 4rem 5rem 4rem;
        display: flex;

        .mixing_left {
            display: flex;
            flex-direction: column;
            flex: 1;
            margin-right: 3rem;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: space-between;

            .mixing_left_num {
                position: relative;
                overflow: hidden;
                padding: 1rem;
                flex: 3.2;
                width: 100%;
                background: url("../../assets/mixing/mixing_left_bg.png") no-repeat;
                background-size: 100% 100%;

                > div {
                    display: flex;
                    justify-content: center;
                    align-items: center;
                    width: 100%;
                    height: 100%;
                    color: rgba(254, 252, 94, 1);
                    font-size: 44rem;
                    font-weight: bold;
                    background-color: rgba(37, 129, 255, 0.29);
                }
            }

            .mixing_left_name {
                flex: 1;
                width: 100%;
                display: flex;
                justify-content: center;
                align-items: center;
                text-shadow: 5px 7px 0px rgba(0, 66, 255, 0.2), 16px 23px 16px rgba(14, 19, 48, 0.15);
                background: linear-gradient(to bottom, #FFFFFF 0%, rgba(140, 186, 255, 0.88) 100%);
                background-clip: text;
                -webkit-background-clip: text;
                -webkit-text-fill-color: transparent;
                color: #FFFFFF;
                font-size: 9rem;
                font-weight: 500;
            }
        }

        .mixing_right {
            flex: 1.2;
            background: linear-gradient(to right, #0D3776 0%, #041A40 100%);
            display: flex;
            flex-direction: column;
            justify-content: space-around;
            padding: 2rem 4rem;

            .mixing_rows {
                overflow: hidden;
                display: flex;

                .mixing_rows_titles {
                    color: #FFFFFF;
                    font-weight: 400;
                    font-size: 5rem;
                }

                .mixing_rows_datas {
                    overflow: hidden;
                    flex: 1;
                    color: #FFFFFF;
                    font-weight: 400;
                    font-size: 5rem;
                    white-space: pre-wrap;

                    &.small_size {
                        font-size: 4.3rem;
                    }
                }

                .standardStyle {
                    color: #15EF48;
                    font-size: 8rem;
                }

                .notStandardStyle {
                    color: rgba(255, 102, 0, 1);
                    font-size: 8rem;
                }
            }
        }
    }
}
</style>